@@ -8,7 +8,7 @@ urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
 
 __all__ = ['generate_ai_plugins_classes']
 
-IF_PLUGINS = ["ZBA042022", "AAR072022", "ABA092022", "ABY122023", "DBT042023", "ACS042023", "MBI042022", "SFI122022", "KBN062023", "OVM012024", "ATR122022", "ZVM062022", "ZSY062022", "ZFN032022", "ALM012024", "GWF092023", "RST062023", "QLC092022", "GDM082023", "ADY122023", "ACF082023", "SNF092022", "AAT052023", "ADF062021", "AEM072022", "BOO032022", "GDQ112023", "GBQ102022", "ABK042023", "ASM0220223", "ICS032022", "AMM082023", "ASF012023", "GDR052023", "ZDX112021", "ZRM082023", "BAK092023", "GFU012023", "GDF032022", "ADO112023", "GLU062021", "GBA032023", "DBX032022", "ZLA112022", "AEC082022", "ADP122022", "COM032023", "AQS012023", "ZML022023", "MFW022023", "GDU102023", "TAB072023", "ADB112022", "TDM052022", "GDP042022", "TER102023", "UIP072021", "GVM062022", "AHD062022", "SOP072023", "MFL022023"]
+IF_PLUGINS = ["GDF032022", "ACF082023", "TAB072023", "QLC092022", "GDM082023", "UIP072021", "ADO112023", "OVM012024", "ACS042023", "ZBA042022", "GBA032023", "AHD062022", "ODI032024", "SNF092022", "ADF062021", "ANS032024", "JEN022024", "DBT042023", "COM032023", "AAT052023", "GBQ102022", "ZVM062022", "GDR052023", "MFL022023", "BAK092023", "ALM012024", "TER102023", "ZFN032022", "MFW022023", "ICS032022", "GDQ112023", "ABY122023", "ABK042023", "ADB112022", "ABA092022", "GDU102023", "TDM052022", "ASM0220223", "ADP122022", "ZLA112022", "GWF092023", "GLU062021", "ZSY062022", "ZML022023", "AEM072022", "KBN062023", "GFU012023", "AQS012023", "GDP042022", "GVM062022", "RST062023", "MBI042022", "ADY122023", "ATR122022", "AAR072022", "BOO032022", "ZRM082023", "AEC082022", "SOP072023", "ASQ032024", "AMM082023", "ASF012023", "ZDX112021", "SFI122022", "DBX032022"]
 
 
 imports_str = '''from aapi import *
